@@ -35,11 +35,7 @@
 #include <QMessageBox>
 #include <QFileIconProvider>
 #include <QDesktopServices>
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-#include <QWebEngineDownloadItem>
-#else
 #include <QWebEngineDownloadRequest>
-#endif
 #include <QtWebEngineWidgetsVersion>
 
 #ifdef Q_OS_WIN
@@ -49,7 +45,7 @@
 
 //#define DOWNMANAGER_DEBUG
 
-DownloadItem::DownloadItem(QListWidgetItem *item, Q_WEB_ENGINE_DOWNLOAD_ITEM_CLASS* downloadItem, const QString &path, const QString &fileName, bool openFile, DownloadManager* manager)
+DownloadItem::DownloadItem(QListWidgetItem *item, QWebEngineDownloadRequest* downloadItem, const QString &path, const QString &fileName, bool openFile, DownloadManager* manager)
     : QWidget()
     , ui(new Ui::DownloadItem)
     , m_item(item)
@@ -85,14 +81,9 @@ DownloadItem::DownloadItem(QListWidgetItem *item, Q_WEB_ENGINE_DOWNLOAD_ITEM_CLA
 
 void DownloadItem::startDownloading()
 {
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    connect(m_download, &QWebEngineDownloadItem::finished, this, &DownloadItem::finished);
-    connect(m_download, &QWebEngineDownloadItem::downloadProgress, this, &DownloadItem::downloadProgress);
-#else
     connect(m_download, &QWebEngineDownloadRequest::isFinishedChanged, this, &DownloadItem::finished);
     connect(m_download, &QWebEngineDownloadRequest::receivedBytesChanged, this, &DownloadItem::receivedOrTotalBytesChanged);
     connect(m_download, &QWebEngineDownloadRequest::totalBytesChanged, this, &DownloadItem::receivedOrTotalBytesChanged);
-#endif
 
     m_downloading = true;
     if (!m_downTimer.isValid()) {
@@ -133,16 +124,16 @@ void DownloadItem::finished()
     QString host = m_download->url().host();
 
     switch (m_download->state()) {
-    case Q_WEB_ENGINE_DOWNLOAD_ITEM_CLASS::DownloadCompleted:
+    case QWebEngineDownloadRequest::DownloadCompleted:
         success = true;
         ui->downloadInfo->setText(tr("Done - %1 (%2)").arg(host, QLocale().toString(QDateTime::currentDateTime(), QLocale::ShortFormat)));
         break;
 
-    case Q_WEB_ENGINE_DOWNLOAD_ITEM_CLASS::DownloadInterrupted:
+    case QWebEngineDownloadRequest::DownloadInterrupted:
         ui->downloadInfo->setText(tr("Error - %1").arg(host));
         break;
 
-    case Q_WEB_ENGINE_DOWNLOAD_ITEM_CLASS::DownloadCancelled:
+    case QWebEngineDownloadRequest::DownloadCancelled:
         ui->downloadInfo->setText(tr("Cancelled - %1").arg(host));
         break;
 
@@ -164,15 +155,10 @@ void DownloadItem::finished()
     Q_EMIT downloadFinished(true);
 }
 
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-void DownloadItem::downloadProgress(qint64 received, qint64 total)
-{
-#else
 void DownloadItem::receivedOrTotalBytesChanged()
 {
     qint64 received = m_download->receivedBytes();
     qint64 total = m_download->totalBytes();
-#endif
 #ifdef DOWNMANAGER_DEBUG
     qDebug() << __FUNCTION__ << received << total;
 #endif
@@ -189,7 +175,7 @@ void DownloadItem::receivedOrTotalBytesChanged()
     m_total = total;
 
     updateDownloadInfo(m_currSpeed, m_received, m_total);
-    emit progressChanged(m_currSpeed, m_received, m_total);
+    Q_EMIT progressChanged(m_currSpeed, m_received, m_total);
 }
 
 int DownloadItem::progress()
@@ -318,21 +304,21 @@ void DownloadItem::mouseDoubleClickEvent(QMouseEvent* e)
 void DownloadItem::customContextMenuRequested(const QPoint &pos)
 {
     QMenu menu;
-    menu.addAction(QIcon::fromTheme("document-open"), tr("Open File"), this, &DownloadItem::openFile);
+    menu.addAction(QIcon::fromTheme(QSL("document-open")), tr("Open File"), this, &DownloadItem::openFile);
 
     menu.addAction(tr("Open Folder"), this, &DownloadItem::openFolder);
     menu.addSeparator();
-    menu.addAction(QIcon::fromTheme("edit-copy"), tr("Copy Download Link"), this, &DownloadItem::copyDownloadLink);
+    menu.addAction(QIcon::fromTheme(QSL("edit-copy")), tr("Copy Download Link"), this, &DownloadItem::copyDownloadLink);
     menu.addSeparator();
-    menu.addAction(QIcon::fromTheme("process-stop"), tr("Cancel downloading"), this, &DownloadItem::stop)->setEnabled(m_downloading);
+    menu.addAction(QIcon::fromTheme(QSL("process-stop")), tr("Cancel downloading"), this, &DownloadItem::stop)->setEnabled(m_downloading);
 
     if (m_download->isPaused()) {
-        menu.addAction(QIcon::fromTheme("media-playback-start"), tr("Resume downloading"), this, &DownloadItem::pauseResume)->setEnabled(m_downloading);
+        menu.addAction(QIcon::fromTheme(QSL("media-playback-start")), tr("Resume downloading"), this, &DownloadItem::pauseResume)->setEnabled(m_downloading);
     } else {
-        menu.addAction(QIcon::fromTheme("media-playback-pause"), tr("Pause downloading"), this, &DownloadItem::pauseResume)->setEnabled(m_downloading);
+        menu.addAction(QIcon::fromTheme(QSL("media-playback-pause")), tr("Pause downloading"), this, &DownloadItem::pauseResume)->setEnabled(m_downloading);
     }
 
-    menu.addAction(QIcon::fromTheme("list-remove"), tr("Remove From List"), this, &DownloadItem::clear)->setEnabled(!m_downloading);
+    menu.addAction(QIcon::fromTheme(QSL("list-remove")), tr("Remove From List"), this, &DownloadItem::clear)->setEnabled(!m_downloading);
 
     if (m_downloading || ui->downloadInfo->text().startsWith(tr("Cancelled")) || ui->downloadInfo->text().startsWith(tr("Error"))) {
         menu.actions().at(0)->setEnabled(false);
@@ -373,8 +359,8 @@ void DownloadItem::openFolder()
         winFileName.append(QSL(".download"));
     }
 
-    winFileName.replace(QLatin1Char('/'), "\\");
-    QString shExArg = "/e,/select,\"" + winFileName + "\"";
+    winFileName.replace(QLatin1Char('/'), QSL("\\"));
+    QString shExArg = QSL("/e,/select,\"") + winFileName + QSL("\"");
     ShellExecute(NULL, NULL, TEXT("explorer.exe"), shExArg.toStdWString().c_str(), NULL, SW_SHOW);
 #else
     QDesktopServices::openUrl(QUrl::fromLocalFile(m_path));
